@@ -48,7 +48,8 @@ switch (nvl($mode)) {
 		validate_product_name($HTTP_POST_VARS["name"], &$errors, &$errormsg);
 		validate_price($HTTP_POST_VARS["price"], &$errors, &$errormsg);
 		validate_discount($HTTP_POST_VARS["discount"], $HTTP_POST_VARS["discqty"], &$errors, &$errormsg);
-		validate_weight($HTTP_POST_VARS["weight"], &$errors, &$errormsg);
+		if($SESSION["weight_used"])
+			validate_weight($HTTP_POST_VARS["weight"], &$errors, &$errormsg);
 		validate_on_special($HTTP_POST_VARS["on_special"], &$errors, &$errormsg);
 		validate_product_description($HTTP_POST_VARS["description"], &$errors, &$errormsg);
 		validate_product_extended_description($HTTP_POST_VARS["extended_description"], &$errors, &$errormsg);
@@ -112,7 +113,8 @@ switch (nvl($mode)) {
 		validate_product_name($HTTP_POST_VARS["name"], &$errors, &$errormsg);
 		validate_price($HTTP_POST_VARS["price"], &$errors, &$errormsg);
 		validate_discount($HTTP_POST_VARS["discount"], $HTTP_POST_VARS["discqty"], &$errors, &$errormsg);
-		validate_weight($HTTP_POST_VARS["weight"], &$errors, &$errormsg);
+		if($SESSION["weight_used"])
+			validate_weight($HTTP_POST_VARS["weight"], &$errors, &$errormsg);
 		validate_product_description($HTTP_POST_VARS["description"], &$errors, &$errormsg);
 		validate_product_extended_description($HTTP_POST_VARS["extended_description"], &$errors, &$errormsg);
 		if (empty($errormsg)) {
@@ -338,7 +340,11 @@ function print_details_product($product_id) {
 	include ($CFG->global);
 
 	/* load up the information for the product */
-	$qid = db_query("SELECT * FROM products WHERE id = '$product_id'");
+	$qid = db_query("
+	SELECT p.* , b.name AS bname
+	FROM products p JOIN brands b ON (p.brand_id = b.id)
+	WHERE p.id = '$product_id'
+	");
 	$frm = db_fetch_array($qid, 0);
 
 	/* load up the categories for the product */
@@ -630,7 +636,7 @@ foreach($HTTP_POST_FILES['userfile'] as $k => $v) {
 }
 
 function print_product_list() {
-/* read all the products from the database and print them into a table.  we
+/* read all the categories from the database and print them into a table.  we
  * will use a template to display the listings to keep this main script clean */
 
 	global $CFG, $ME;
@@ -779,7 +785,7 @@ function import_products($HTTP_POST_FILES) {
 
 			/* ... and let's see if the product already exists ... */
 			$qid = db_query("
-			SELECT id, name FROM products WHERE id = '$fldarr[1]'
+			SELECT id, name FROM products WHERE id = '$fldarr[6]'
 			");
 			if (db_num_rows($qid) == 0) {
 				/* ... if it doesn't exist let's create it in the products table ... */
