@@ -33,8 +33,6 @@ $CFG->dbpass = "postgres";
 
 $CFG->myname = "PgMarket 1.3.x";
 
-$frames=1;
-
 $CFG->wwwroot     = "/~pratesi/pgmarket";	// without an ending "/"
 $CFG->firstpage   = "$CFG->wwwroot/firstpage.php";
 $CFG->dirroot     = "/home/pratesi/public_html/pgmarket";	// without an ending "/"
@@ -80,9 +78,16 @@ if (! isset($SESSION)) {
 }
 
 // Loaded modules
+$SESSION["frames_used"] = 1;
+$SESSION["catbrowser_target"] = "bodyframe";
+//$SESSION["frames_used"] = 0;
+//$SESSION["catbrowser_target"] = "main";
+$SESSION["layersmenu_used"] = 1;
 $SESSION["brand_used"] = 1;
 $SESSION["iva_used"] = 1;
-//$SESSION["iva_value"] = 0;	// not significant if IVA is not used
+//$SESSION["iva_value"] = 0;	// not significant if IVA is used
+$SESSION["weight_used"] = 1;
+$SESSION["delivery_used"] = 1;
 
 $SESSION["price_must_be_integer"] = 1;
 	// 1 --> the price must be integer (Italian Lit, for example)
