@@ -35,8 +35,8 @@ function load_on_specials(&$qid) {
 	include ($CFG->global);
 
 	$qid = db_query("
-			SELECT *
-			FROM products
+			SELECT p.* , b.name AS bname
+			FROM products p JOIN brands b ON (p.brand_id = b.id)
 			WHERE on_special > $special_th
 			ORDER BY on_special ASC
 			");
