@@ -1,12 +1,12 @@
 <? /* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */
    include("application.inc.php");
-   if ($frames) {
+   if ($SESSION["frames_used"]) {
 ?>
 
 <html>
 <frameset cols="180,*" framespacing=0 frameborder=no border=0>
-<frame name="categories" src="shopping/navigation.php?p=0" target="main">
-<frame name="main" src="<?=$CFG->firstpage?>">
+<frame name="categories" src="shopping/navigation.php?p=0" target="bodyframe">
+<frame name="bodyframe" src="<?=$CFG->firstpage?>">
 </frameset>
 </html>
 
