@@ -199,7 +199,7 @@ function find_products($stringtsf_stripped, $case_sensitive=0, $concatenation) {
 	$l_array_of_elements = explode(" ",$stringtsf_stripped);
 	foreach($l_array_of_elements as $l_search_element){
 		if ($l_search_element != "") 
-			$l_search_condition.="(name $l_matches_regex '$l_search_element' OR description $l_matches_regex '$l_search_element' OR extended_description $l_matches_regex '$l_search_element') $concatenation ";
+			$l_search_condition.="(p.name $l_matches_regex '$l_search_element' OR p.description $l_matches_regex '$l_search_element' OR p.extended_description $l_matches_regex '$l_search_element') $concatenation ";
 	}
 
 	if ($concatenation == "OR") {
@@ -208,7 +208,11 @@ function find_products($stringtsf_stripped, $case_sensitive=0, $concatenation) {
 		$l_search_condition.="TRUE";
 	}
 
-	$qid = db_query("SELECT * FROM products WHERE $l_search_condition ORDER BY name");
+	$qid = db_query("
+	SELECT p.* , b.name AS bname
+	FROM products p JOIN brands b ON (p.brand_id = b.id)
+	WHERE $l_search_condition ORDER BY p.name , b.name
+	");
 
 	return $qid;
 }
@@ -219,11 +223,11 @@ function advanced_find_products($frm) {
 
 	// Prepare for searching products with name within a limited range
 	if (!empty($frm["product_name_min"]))
-		$l_search_condition = "(name >= '$frm[product_name_min]')";
+		$l_search_condition = "(p.name >= '$frm[product_name_min]')";
 	if (!empty($frm[product_name_max])) {
 		if (!empty($l_search_condition))
 			$l_search_condition .= " AND ";
-		$l_search_condition .= "(name <= '$frm[product_name_max]')";
+		$l_search_condition .= "(p.name <= '$frm[product_name_max]')";
 	}
 	
 	// Prepare for searching words in the product name
@@ -241,7 +245,7 @@ function advanced_find_products($frm) {
 		$prod_l_search_condition = "(";
 		foreach($l_array_of_elements as $l_search_element) {
 			if ($l_search_element != "") 
-				$prod_l_search_condition.="(name $prod_l_matches_regex '$l_search_element') $prod_concatenation ";
+				$prod_l_search_condition.="(p.name $prod_l_matches_regex '$l_search_element') $prod_concatenation ";
 		}
 
 		if ($prod_concatenation == "OR") {
@@ -266,12 +270,12 @@ function advanced_find_products($frm) {
 	if (!empty($frm[description_min])) {
 		if (!empty($l_search_condition))
 			$l_search_condition .= " AND ";
-		$l_search_condition .= "(description >= '$frm[description_min]')";
+		$l_search_condition .= "(p.description >= '$frm[description_min]')";
 	}
 	if (!empty($frm[description_max])) {
 		if (!empty($l_search_condition))
 			$l_search_condition .= " AND ";
-		$l_search_condition .= "(description <= '$frm[description_max]')";
+		$l_search_condition .= "(p.description <= '$frm[description_max]')";
 	}
 
 	// Prepare for searching words in the product description
@@ -289,7 +293,7 @@ function advanced_find_products($frm) {
 		$desc_l_search_condition = "(";
 		foreach($l_array_of_elements as $l_search_element) {
 			if ($l_search_element != "") 
-				$desc_l_search_condition.="(description $desc_l_matches_regex '$l_search_element' OR extended_description $desc_l_matches_regex '$l_search_element') $desc_concatenation ";
+				$desc_l_search_condition.="(p.description $desc_l_matches_regex '$l_search_element' OR p.extended_description $desc_l_matches_regex '$l_search_element') $desc_concatenation ";
 		}
 
 		if ($desc_concatenation == "OR") {
@@ -352,7 +356,11 @@ function advanced_find_products($frm) {
 		$l_search_condition .= "(weight <= '$frm[weight_max]')";
 	}
 
-	$qid = db_query("SELECT * FROM products WHERE $l_search_condition ORDER BY name");
+	$qid = db_query("
+	SELECT p.* , b.name AS bname
+	FROM products p JOIN brands b ON (p.brand_id = b.id)
+	WHERE $l_search_condition ORDER BY p.name , b.name
+	");
 
 	return $qid;
 }
