@@ -94,27 +94,27 @@ function build_category_tree(&$output, &$preselected, $parent=1, $indent="") {
 	}
 }
 
-function build_category_navigator(&$output, $parent=1, $indent="..") {
+function build_catbrowser(&$output, $parent=1, $indent="..") {
 /* recursively go through the category tree, starting at a parent, and
  * drill down, printing options for a selection list box.
  * this is not an efficient algorithm because it has to issue
  * one query per category!!  it's only used because it is easy to understand.
  */
-	global $CFG;
+	global $CFG, $SESSION;
 
         $qid = db_query("SELECT id, name FROM categories WHERE parent_id = '$parent' AND id <> 1 ORDER BY on_special, name");
 
         $numr = db_num_rows($qid);
         for ($i=0;$i<$numr;$i++) {
                 $cat =  db_fetch_object($qid, $i);
-		$output .= $indent . $cat->name . "^" . $CFG->wwwroot . "/shopping/?" . getenv("QUERY_STRING") . "&id=" . $cat->id . "^main" . "\n";
+		$output .= $indent . $cat->name . "^" . $CFG->wwwroot . "/shopping/?" . getenv("QUERY_STRING") . "&id=" . $cat->id . "^" . $SESSION["catbrowser_target"] . "\n";
                 if ($cat->id != $parent) {
-                        build_category_navigator($output, $cat->id, $indent.".");
+                        build_catbrowser($output, $cat->id, $indent.".");
                 }
         }
 }
 
-function build_category_navigator_js(&$output, $parent=1, $indent="..") {
+function build_catbrowser_js(&$output, $parent=1, $indent="..") {
 /* recursively go through the category tree, starting at a parent, and
  * drill down, printing options for a selection list box.
  * this is not an efficient algorithm because it has to issue
@@ -132,7 +132,7 @@ function build_category_navigator_js(&$output, $parent=1, $indent="..") {
 //		else
 //			$output .= $indent . $cat->name . "^" . $CFG->wwwroot . "/shopping/?" . getenv("QUERY_STRING") . "&id=" . $cat->id . "\n";
                 if ($cat->id != $parent) {
-                        build_category_navigator_js($output, $cat->id, $indent.".");
+                        build_catbrowser_js($output, $cat->id, $indent.".");
                 }
         }
 }
