@@ -102,6 +102,8 @@ $All_the_words = "Tutte le parole";
 $Case_Sensitive = "Distingui Maiuscole";
 $Search_excl = "Cerca !";
 $Insufficient_Privileges = "Diritti insufficienti";
+$No_Orders = "Nessun Ordine";
+$No_Such_Order = "Non c'&egrave; nessun ordine con l'identificativo richiesto";
 $PgMarket_Login = $CFG->myname . " Login";
 $PgMarket_Login_Page = $CFG->myname . ": pagina di login";
 $sign_up_for_an_account_now = "Se non sei gi&agrave; iscritto a questo negozio elettronico, iscriviti ora:";
@@ -388,7 +390,7 @@ $customer_too_long = "Campo Cliente troppo lungo: " . $appoggio . " caratteri ma
 $empty_contact = "Non &egrave; stato specificato un recapito telefonico";
 $contact_too_long = "Recapito telefonico troppo lungo: ".$SESSION["phone_length"]." caratteri max";
 $contact_too_short = "Recapito telefonico troppo corto: ".$SESSION["phone_length_min"]." caratteri min";
-$not_valid_contact = "Recapito telefonico non valido";
+$not_valid_contact = "Recapito telefonico non valido; sono ammessi solo spazi, cifre e i seguenti caratteri: +-()/";
 $comments_too_long = "Commenti troppo lunghi: ".$SESSION["comments_length"]." caratteri max";
 
 ////////////////////////////////////////////////////////////
