@@ -102,6 +102,8 @@ $All_the_words = "All the words";
 $Case_Sensitive = "Case Sensitive";
 $Search_excl = "Search !";
 $Insufficient_Privileges = "Insufficient Privileges";
+$No_Orders = "No Orders";
+$No_Such_Order = "There is not any order with the requested identifier";
 $PgMarket_Login = $CFG->myname . " Login";
 $PgMarket_Login_Page = $CFG->myname . ": Login Page";
 $sign_up_for_an_account_now = "If you do not already have an account, please sign up for an account now:";
@@ -385,7 +387,7 @@ $customer_too_long = "Customer too much long: " . $appoggio . " characters max";
 $empty_contact = "You did not specify a Phone to contact you";
 $contact_too_long = "Contact Phone number too much long: ".$SESSION["phone_length"]." characters max";
 $contact_too_short = "Contact Phone number too much short: ".$SESSION["phone_length_min"]." characters min";
-$not_valid_contact = "Contact Phone number not valid";
+$not_valid_contact = "Contact Phone number not valid; only cyphers, spaces, +-()/ are allowed characters";
 $comments_too_long = "Comments too much long: ".$SESSION["comments_length"]." characters max";
 
 ////////////////////////////////////////////////////////////
