@@ -21,8 +21,8 @@ include("../application.inc.php");
 <tr valign=top>
 <td class=normal>
 <?
-build_category_navigator($categories);
-$categories = ".Top^" . $CFG->wwwroot . "/shopping/^main\n" . $categories;
+build_catbrowser($categories);
+$categories = ".Top^" . $CFG->wwwroot . "/shopping/^" . $SESSION["catbrowser_target"] . "\n" . $categories;
 require("$CFG->libdir/treemenu.inc.php");
 ?>
 </td>
