@@ -62,7 +62,6 @@ function load_product($product_id) {
 	SELECT
 		 p.id
 		,p.name
-		,p.brand_id
 		,p.price
 		,p.iva_id
 		,p.discount
@@ -77,11 +76,9 @@ function load_product($product_id) {
 		,p.thumbwidth
 		,p.thumbheight
 		,pc.category_id
-	FROM
-		 products p
-		,products_categories pc
-	WHERE p.id = pc.product_id
-		AND p.id = '$product_id'
+		,b.name
+	FROM products p JOIN products_categories pc ON (p.id = pc.product_id) JOIN brands b ON (p.brand_id = b.id)
+	WHERE p.id = '$product_id'
 	");
 
 	if ($qid) {
