@@ -14,11 +14,11 @@ if (!strpos($REFERER_AND_QUERY, "from_menu=yes")) {
 		$REFERER_AND_QUERY = $REFERER_AND_QUERY . "&from_menu=yes";
 	}
 }
-if ($frames) { ?>
+if ($SESSION["frames_used"]) { ?>
 <script language="JavaScript">
 <!--
 parent.categories.location.reload();
-parent.main.location.href="<?=$REFERER_AND_QUERY?>";
+parent.bodyframe.location.href="<?=$REFERER_AND_QUERY?>";
 // -->
 </script>
 <?
