@@ -8,7 +8,7 @@
 
 include("../application.inc.php");
 
-/* form has been submitted, try to create the new user account */
+/* form has been submitted, try to send the message */
 if (match_referer() && isset($HTTP_POST_VARS) && !isset($from_menu)) {
 	$frm = $HTTP_POST_VARS;
 	$errormsg = validate_form($frm, $errors, $usertype);
@@ -68,6 +68,7 @@ function send_form(&$frm) {
 
 	global $CFG, $SESSION;
 	global $subject_contact, $contact;
+	include ($CFG->global);
 
 	$emailbody = "";
 	$emailbody .= $contact[NameOrEnterpriseName] . stripslashes($frm["name"]);
@@ -75,7 +76,7 @@ function send_form(&$frm) {
 	$emailbody .= " " . stripslashes($frm["number"]);
 	$emailbody .= "\n" . stripslashes($frm["city"]);
 	$emailbody .= "\n" . stripslashes($frm["state"]);
-	$emailbody .= "\n" . stripslashes($frm["zip_code"]);
+	$emailbody .= "\n" .   $Zip_Code . ": " . stripslashes($frm["zip_code"]);
 	$emailbody .= "\n\n" . $contact[Phone] . $frm["phone"];
 	$emailbody .= "\n\n" . $contact[Fax] . $frm["fax"];
 	$emailbody .= "\n\n" . $contact[MobilePhone] . $frm["mobilephone"];
